@@ -19,7 +19,6 @@
 
 #include "config.h"
 
-#include <errno.h>
 #include <gconf/gconf.h>
 #include <glade/glade.h>
 #include <gnome.h>
@@ -267,12 +266,6 @@ read_config(void)
 	if (GTT_NO_ERR != conf_errcode) 
 	{
 		const char *fp, *errmsg, *qmsg;
-		if (errno == ENOENT) 
-		{
-			errno = 0;
-			return;
-		}
-
 		fp = gtt_get_config_filepath();
 		errmsg = gtt_err_to_string (conf_errcode, fp);
 		qmsg = g_strconcat (errmsg, 
@@ -293,8 +286,8 @@ read_config(void)
 	}
 }
 
-
-
+#if 0
+/* used only to display development version warning messsage */
 static void 
 beta_run_or_abort(GtkWidget *w, gint butnum)
 {
@@ -307,6 +300,7 @@ beta_run_or_abort(GtkWidget *w, gint butnum)
 		read_config();
 	}
 }
+#endif
 
 /* save_all() is a bit sloppy, in that if we get two errors in a row,
  * we'll miss the second one ... but what the hey, who cares.
